@@ -20,7 +20,6 @@ DARK_DIR=`realpath $THIS_DIR/../../share/skins/$DARK`
 S_ICON=22x22     # Size of icons in menus and toolbars
 S_PLAY=36x36     # Size of icons in player
 S_INFO=64x64     # Size of icons in warnings and settings dialog
-S_LOGO=96x96     # Size of TuxGuitar logo
 S_TRAC=16x16     # Size of icons in track table
 
 # Icon colors
@@ -32,12 +31,16 @@ C_D_HI=-20%      # Modify brightness for highlighted icons, dark mode
 
 declare -A ICONS=(
   # Icon path/name.svg -convert-> width1xheight1:TuxGuitar_icon1.png width2xheight2+margin2:TuxGuitar_icon2.png width3xheight3+margin3-H:TuxGuitar_icon3.png
-  # Icon path/name.png -convert-> width1xheight1:TuxGuitar_icon1.png width2xheight2:TuxGuitar_icon2.png
   # Icon path/file.xyz --copy---> $SKIN_DIR/file1.xyz                $DARK_DIR/file2.xyz
+  ["$DT/actions/22/filename-divider.svg"]="$S_ICON:separator.png"
+  ["$TG/duration.svg"]="$S_ICON:duration.png"
   ["$TG/1.svg"]="$S_ICON:1.png"
   ["$TG/2.svg"]="$S_ICON:2.png"
+  ["$TG/2dotted.svg"]="$S_ICON:2dotted.png"
   ["$TG/4.svg"]="$S_ICON:4.png"
+  ["$TG/4dotted.svg"]="$S_ICON:4dotted.png"
   ["$TG/8.svg"]="$S_ICON:8.png"
+  ["$TG/8dotted.svg"]="$S_ICON:8dotted.png"
   ["$TG/16.svg"]="$S_ICON:16.png"
   ["$TG/32.svg"]="$S_ICON:32.png"
   ["$TG/64.svg"]="$S_ICON:64.png"
@@ -52,8 +55,10 @@ declare -A ICONS=(
   ["$TG/edit_voice_2.svg"]="$S_ICON:edit_voice_2.png"
   ["$DT/actions/22/edit-select.svg"]="$S_ICON:edit_mode_selection.png"
   ["$TG/edit_mode_edition_no_natural.svg"]="$S_ICON:edit_mode_edition_no_natural.png"
+  ["$TG/edit_mode_free.svg"]="$S_ICON:edit_mode_free.png"
   ["$TG/timesignature.svg"]="$S_ICON:timesignature.png"
   ["$DT/preferences/22/preferences-system-time.svg"]="$S_ICON:tempoicon.png"
+  ["$TG/tempoindicator.svg"]="$S_ICON:tempoindicator.png"
   ["$TG/clef.svg"]="$S_ICON:clef.png"
   ["$TG/keysignature.svg"]="$S_ICON:keysignature.png"
   ["$TG/tripletfeel.svg"]="$S_ICON:tripletfeel.png"
@@ -62,6 +67,7 @@ declare -A ICONS=(
   ["$TG/repeat_alternative.svg"]="$S_ICON:repeat_alternative.png"
   ["$TG/dotted.svg"]="$S_ICON:dotted.png"
   ["$TG/doubledotted.svg"]="$S_ICON:doubledotted.png"
+  ["$TG/division-type.svg"]="$S_ICON:division-type.png"
   ["$TG/division-type-1.svg"]="$S_ICON:division-type-1.png"
   ["$TG/division-type-3.svg"]="$S_ICON:division-type-3.png"
   ["$TG/division-type-5.svg"]="$S_ICON:division-type-5.png"
@@ -75,12 +81,13 @@ declare -A ICONS=(
   ["$TG/fretboard.svg"]="$S_ICON:fretboard.png"
   ["$TG/fretboard_smaller.svg"]="$S_ICON:fretboard_smaller.png"
   ["$TG/fretboard_bigger.svg"]="$S_ICON:fretboard_bigger.png"
-  ["$TG/firstfret.svg"]="1x50:firstfret.png"
+  ["$TG/firstfret.svg"]="5x50:firstfret.png"
   ["$TG/fret.svg"]="2x45:fret.png"
   ["$TG/chord.svg"]="$S_ICON:chord.png"
   ["$TG/text.svg"]="$S_ICON:text.png"
   ["$TG/tiednote.svg"]="$S_ICON:tiednote.png"
   ["$TG/mixer.svg"]="$S_ICON:mixer.png"
+  ["$TG/dynamic.svg"]="$S_ICON:dynamic.png"
   ["$TG/dynamic_ppp.svg"]="$S_ICON:dynamic_ppp.png"
   ["$TG/dynamic_pp.svg"]="$S_ICON:dynamic_pp.png"
   ["$TG/dynamic_p.svg"]="$S_ICON:dynamic_p.png"
@@ -111,6 +118,9 @@ declare -A ICONS=(
   ["$TG/effect_fade_in.svg"]="$S_ICON:effect_fade_in.png"
   ["$TG/stroke_up.svg"]="$S_ICON:stroke_up.png"
   ["$TG/stroke_down.svg"]="$S_ICON:stroke_down.png"
+  ["$TG/pick_stroke_up.svg"]="$S_ICON:pick_stroke_up.png"
+  ["$TG/pick_stroke_down.svg"]="$S_ICON:pick_stroke_down.png"
+  ["$TG/alt_enharmonic.svg"]="$S_ICON:alt_enharmonic.png"
   ["$DT/actions/22/configure.svg"]="$S_ICON:settings.png"
   ["$DT/actions/22/document-new.svg"]="$S_ICON:new.png"
   ["$DT/actions/22/document-open.svg"]="$S_ICON:open.png"
@@ -135,12 +145,11 @@ declare -A ICONS=(
   ["$DT/actions/22/zoom-original.svg"]="$S_ICON:zoom_original.png"
   ["$DT/actions/22/zoom-out.svg"]="$S_ICON:zoom_out.png"
   ["$DT/actions/22/list-add.svg"]="$S_ICON:list_add.png $S_ICON:track_add.png $S_ICON:measure_add.png"
-  ["$DT/actions/22/list-remove.svg"]="$S_ICON:list_remove.png $S_ICON:track_remove.png $S_ICON:measure_remove.png $S_TRAC-H:mute-disabled.png $S_TRAC:mute-disabled-dim.png $S_TRAC-H:solo-disabled.png $S_TRAC:solo-disabled-dim.png"
+  ["$DT/actions/22/paint-none.svg"]="$S_ICON:list_remove.png $S_ICON:track_remove.png $S_ICON:measure_remove.png"
   ["$DT/devices/22/audio-headphones.svg"]="$S_ICON:track_solo.png $S_TRAC-H:solo.png $S_TRAC:solo-dim.png"
   ["$DT/status/22/audio-volume-muted.svg"]="$S_ICON:track_mute.png $S_TRAC-H:mute.png $S_TRAC:mute-dim.png"
+  ["$DT/actions/22/value-decrease.svg"]="$S_TRAC-H:solo-disabled.png $S_TRAC:solo-disabled-dim.png $S_TRAC-H:mute-disabled.png $S_TRAC:mute-disabled-dim.png"
   ["$DT/actions/22/document-edit.svg"]="$S_ICON:list_edit.png $S_ICON:edit_mode_edition.png"
-  ["$DT/actions/22/go-down-skip.svg"]="$S_ICON:list_move_up.png"
-  ["$DT/actions/22/go-up-skip.svg"]="$S_ICON:list_move_down.png"
   ["$TG/sidebar-expand-left_top.svg"]="$S_ICON:toolbar_main.png"
   ["$DT/actions/22/sidebar-expand-left.svg"]="$S_ICON:toolbar_edit.png"
   ["$TG/sidebar-expand-left_bottom.svg"]="$S_ICON:table_viewer.png"
@@ -159,12 +168,17 @@ declare -A ICONS=(
   ["$DT/actions/22/bookmarks.svg"]="$S_ICON:marker_list.png $S_ICON:marker.png"
   ["$DT/actions/22/go-top.svg"]="$S_ICON:track_first.png"
   ["$DT/actions/22/go-bottom.svg"]="$S_ICON:track_last.png"
-  ["$DT/actions/22/go-up.svg"]="$S_ICON:track_previous.png $S_ICON:arrow_up.png"
-  ["$DT/actions/22/go-down.svg"]="$S_ICON:track_next.png $S_ICON:arrow_down.png"
+  ["$DT/actions/22/go-up-skip.svg"]="$S_ICON:track_previous.png"
+  ["$DT/actions/22/go-down-skip.svg"]="$S_ICON:track_next.png"
+  ["$DT/actions/22/go-up.svg"]="$S_ICON:arrow_up.png"
+  ["$DT/actions/22/go-down.svg"]="$S_ICON:arrow_down.png"
   ["$DT/actions/22/go-first.svg"]="$S_ICON:marker_first.png $S_ICON:measure_first.png"
   ["$DT/actions/22/go-previous.svg"]="$S_ICON:marker_previous.png $S_ICON:measure_previous.png $S_ICON:browser_back.png $S_ICON:arrow_left.png"
   ["$DT/actions/22/go-next.svg"]="$S_ICON:marker_next.png $S_ICON:measure_next.png $S_ICON:arrow_right.png"
   ["$DT/actions/22/go-last.svg"]="$S_ICON:marker_last.png $S_ICON:measure_last.png"
+  ["$TG/measure_status_check.svg"]="$S_ICON:measure_status_check.png"
+  ["$DT/actions/22/dialog-ok-apply.svg"]="$S_ICON:measure_status_ok.png"
+  ["$DT/actions/22/window-close.svg"]="$S_ICON:measure_status_error.png"
   ["$DT/preferences/22/preferences-other.svg"]="$S_INFO:option_view.png"
   ["$DT/actions/22/run-build-configure.svg"]="$S_ICON:tools_settings.png"
   ["$DT/actions/22/plugins.svg"]="$S_ICON:tools_plugins.png"
@@ -186,19 +200,21 @@ declare -A ICONS=(
   ["$DT/places/22/folder.svg"]="$S_ICON:browser_folder.png"
   ["$DT/actions/22/document-open-remote.svg"]="$S_ICON:browser_folder_remote.png"
   ["$DT/places/22/folder-sound.svg"]="$S_ICON:browser_collection.png"
-  ["$DT/status/22/dialog-error.svg"]="$S_INFO:status_error.png"
-  ["$DT/status/22/dialog-information.svg"]="$S_INFO:status_info.png"
+  ["$DT/status/22/data-error.svg"]="$S_INFO:status_error.png"
+  ["$DT/status/22/data-information.svg"]="$S_INFO:status_info.png"
   ["$DT/status/22/dialog-question.svg"]="$S_INFO:status_question.png"
-  ["$DT/status/22/dialog-warning.svg"]="$S_INFO:status_warning.png"
+  ["$DT/status/22/data-warning.svg"]="$S_INFO:status_warning.png"
   ["$TG/transport_metronome.svg"]="$S_ICON:transport_metronome.png"
   ["$TG/transport_count_in.svg"]="$S_ICON:transport_count_in.png"
-  ["$TG/logo.png"]="$S_LOGO:icon.png"
+  ["$TG/transport_time_counter.svg"]="$S_ICON:transport_time_counter.png"
+  ["$TG/icon.png"]="$SKIN_DIR/icon.png $DARK_DIR/icon.png"
   ["$TG/splash.png"]="$SKIN_DIR/splash.png $DARK_DIR/splash.png"
   ["$TG/skin-preview.png"]="$SKIN_DIR/skin-preview.png"
   ["$TG/skin-preview-dark.png"]="$DARK_DIR/skin-preview.png"
   ["$TG/skin.info"]="$SKIN_DIR/skin.info"
   ["$TG/skin-dark.info"]="$DARK_DIR/skin.info"
-  ["$TG/skin.prop"]="$SKIN_DIR/skin.prop $DARK_DIR/skin.prop"
+  ["$TG/skin.prop"]="$SKIN_DIR/skin.prop"
+  ["$TG/skin-dark.prop"]="$DARK_DIR/skin.prop"
 
 )
 
@@ -206,7 +222,7 @@ function usage {
   echo
   echo "Usage: $COMMAND [OPTIONS]"
   echo
-  echo "Generate the skins $SKIN and $DARK from the SVG/PNG images in the directory"
+  echo "Generate the skins $SKIN and $DARK from the SVG images in the directory"
   echo "  $THIS_DIR"
   echo "  The subfolder \"$DT\" contains the icons that are taken over from the $DT Desktop without modifications."
   echo "  The subfolder \"$TG\" contains icons and other files that are specific to $TG."
@@ -309,18 +325,10 @@ for icon in "${!ICONS[@]}"; do
         OUT_HILI=$C_D_HI
         OUT_FILE=$DARK_DIR/$png_icon
         convert_svg_to_png
-      elif [[ $icon =~ ^.+\.png$ ]]; then
-        echo -n "Converting to $SKIN_DIR/$png_icon ... "
-        if [ $margin ]; then
-          echo -e "\n\nError: Margin $margin given, but margin is not supported for PNGs."
-          echo -e "\nAborting.\n"
-          exit 1
-        fi
-        gm convert -scale $width"x"$height! $THIS_DIR/$icon $SKIN_DIR/$png_icon
-        echo "done."
-        echo -n "Converting to $DARK_DIR/$png_icon ... "
-        cp -p $SKIN_DIR/$png_icon $DARK_DIR
-        echo "done."
+      else
+        echo -e "\nError: Only SVG files can be converted to PNG icons."
+        echo -e "\nAborting.\n"
+        exit 1
       fi
     elif [[ $out_icon =~ .+/.+ ]]; then
       echo -n "Copying to $out_icon ... "
