@@ -22,7 +22,6 @@ S_ICOS=16x16+3   # Size of icons in menus and toolbars
 S_ICOB=22x22     # Size of icons in menus and toolbars
 S_PLAY=36x36     # Size of icons in player
 S_INFO=64x64     # Size of icons in warnings and settings dialog
-S_LOGO=96x96     # Size of TuxGuitar logo
 S_TRAC=16x16     # Size of icons in track table
 
 # Icon colors are defined in the CSS files
@@ -33,12 +32,16 @@ C_D_HI=-30%                              # Modify brightness for highlighted ico
 
 declare -A ICONS=(
   # Icon path/name.svg -convert-> width1xheight1:TuxGuitar_icon1.png width2xheight2+margin2:TuxGuitar_icon2.png width3xheight3+margin3-H:TuxGuitar_icon3.png
-  # Icon path/name.png -convert-> width1xheight1:TuxGuitar_icon1.png width2xheight2:TuxGuitar_icon2.png
   # Icon path/file.xyz --copy---> $SKIN_DIR/file1.xyz                $DARK_DIR/file2.xyz
+  ["$TG/separator.svg"]="$S_ICOS:separator.png"
+  ["$TG/duration.svg"]="$S_ICOB:duration.png"
   ["$TG/1.svg"]="$S_ICOB:1.png"
   ["$TG/2.svg"]="$S_ICOB:2.png"
+  ["$TG/2dotted.svg"]="$S_ICOB:2dotted.png"
   ["$TG/4.svg"]="$S_ICOB:4.png"
+  ["$TG/4dotted.svg"]="$S_ICOB:4dotted.png"
   ["$TG/8.svg"]="$S_ICOB:8.png"
+  ["$TG/8dotted.svg"]="$S_ICOB:8dotted.png"
   ["$TG/16.svg"]="$S_ICOB:16.png"
   ["$TG/32.svg"]="$S_ICOB:32.png"
   ["$TG/64.svg"]="$S_ICOB:64.png"
@@ -53,8 +56,10 @@ declare -A ICONS=(
   ["$TG/edit_voice_2.svg"]="$S_ICOB:edit_voice_2.png"
   ["$DT/actions/edit-select-symbolic.svg"]="$S_ICOS:edit_mode_selection.png"
   ["$TG/edit_mode_edition_no_natural.svg"]="$S_ICOS:edit_mode_edition_no_natural.png"
+  ["$TG/edit_mode_free.svg"]="$S_ICOS:edit_mode_free.png"
   ["$TG/timesignature.svg"]="$S_ICOB:timesignature.png"
   ["$DT/legacy/preferences-system-time-symbolic.svg"]="$S_ICOS:tempoicon.png"
+  ["$TG/tempoindicator.svg"]="$S_ICOB:tempoindicator.png"
   ["$TG/clef.svg"]="$S_ICOB:clef.png"
   ["$TG/keysignature.svg"]="$S_ICOB:keysignature.png"
   ["$TG/tripletfeel.svg"]="$S_ICOB:tripletfeel.png"
@@ -63,6 +68,7 @@ declare -A ICONS=(
   ["$TG/repeat_alternative.svg"]="$S_ICOB:repeat_alternative.png"
   ["$TG/dotted.svg"]="$S_ICOB:dotted.png"
   ["$TG/doubledotted.svg"]="$S_ICOB:doubledotted.png"
+  ["$TG/division-type.svg"]="$S_ICOB:division-type.png"
   ["$TG/division-type-1.svg"]="$S_ICOB:division-type-1.png"
   ["$TG/division-type-3.svg"]="$S_ICOB:division-type-3.png"
   ["$TG/division-type-5.svg"]="$S_ICOB:division-type-5.png"
@@ -76,12 +82,13 @@ declare -A ICONS=(
   ["$TG/fretboard.svg"]="$S_ICOS:fretboard.png"
   ["$TG/fretboard_smaller.svg"]="$S_ICOS:fretboard_smaller.png"
   ["$TG/fretboard_bigger.svg"]="$S_ICOS:fretboard_bigger.png"
-  ["$TG/firstfret.svg"]="1x50:firstfret.png"
+  ["$TG/firstfret.svg"]="5x50:firstfret.png"
   ["$TG/fret.svg"]="2x45:fret.png"
   ["$TG/chord.svg"]="$S_ICOB:chord.png"
   ["$TG/text.svg"]="$S_ICOB:text.png"
   ["$TG/tiednote.svg"]="$S_ICOB:tiednote.png"
   ["$TG/mixer.svg"]="$S_ICOS:mixer.png"
+  ["$TG/dynamic.svg"]="$S_ICOB:dynamic.png"
   ["$TG/dynamic_ppp.svg"]="$S_ICOB:dynamic_ppp.png"
   ["$TG/dynamic_pp.svg"]="$S_ICOB:dynamic_pp.png"
   ["$TG/dynamic_p.svg"]="$S_ICOB:dynamic_p.png"
@@ -112,6 +119,9 @@ declare -A ICONS=(
   ["$TG/effect_fade_in.svg"]="$S_ICOB:effect_fade_in.png"
   ["$TG/stroke_up.svg"]="$S_ICOB:stroke_up.png"
   ["$TG/stroke_down.svg"]="$S_ICOB:stroke_down.png"
+  ["$TG/pick_stroke_up.svg"]="$S_ICOB:pick_stroke_up.png"
+  ["$TG/pick_stroke_down.svg"]="$S_ICOB:pick_stroke_down.png"
+  ["$TG/alt_enharmonic.svg"]="$S_ICOB:alt_enharmonic.png"
   ["$DT/categories/preferences-system-symbolic.svg"]="$S_ICOS:settings.png"
   ["$DT/actions/document-new-symbolic.svg"]="$S_ICOS:new.png"
   ["$DT/actions/document-open-symbolic.svg"]="$S_ICOS:open.png"
@@ -140,8 +150,6 @@ declare -A ICONS=(
   ["$DT/devices/audio-headphones-symbolic.svg"]="$S_ICOS:track_solo.png $S_TRAC-H:solo.png $S_TRAC:solo-dim.png"
   ["$DT/status/audio-volume-muted-symbolic.svg"]="$S_ICOS:track_mute.png $S_TRAC-H:mute.png $S_TRAC:mute-dim.png"
   ["$DT/actions/document-edit-symbolic.svg"]="$S_ICOS:list_edit.png $S_ICOS:edit_mode_edition.png"
-  ["$DT/ui/pan-up-symbolic.svg"]="$S_ICOS:list_move_up.png"
-  ["$DT/ui/pan-down-symbolic.svg"]="$S_ICOS:list_move_down.png"
   ["$TG/sidebar-show-symbolic_top.svg"]="$S_ICOS:toolbar_main.png"
   ["$DT/actions/sidebar-show-symbolic.svg"]="$S_ICOS:toolbar_edit.png"
   ["$TG/sidebar-show-symbolic_bottom.svg"]="$S_ICOS:table_viewer.png"
@@ -160,12 +168,17 @@ declare -A ICONS=(
   ["$DT/places/user-bookmarks-symbolic.svg"]="$S_ICOS:marker_list.png $S_ICOS:marker.png"
   ["$DT/actions/go-top-symbolic.svg"]="$S_ICOS:track_first.png"
   ["$DT/actions/go-bottom-symbolic.svg"]="$S_ICOS:track_last.png"
-  ["$DT/actions/go-up-symbolic.svg"]="$S_ICOS:track_previous.png $S_ICOS:arrow_up.png"
-  ["$DT/actions/go-down-symbolic.svg"]="$S_ICOS:track_next.png $S_ICOS:arrow_down.png"
+  ["$DT/actions/go-up-symbolic.svg"]="$S_ICOS:track_previous.png"
+  ["$DT/actions/go-down-symbolic.svg"]="$S_ICOS:track_next.png"
+  ["$DT/ui/pan-up-symbolic.svg"]="$S_ICOS:arrow_up.png"
+  ["$DT/ui/pan-down-symbolic.svg"]="$S_ICOS:arrow_down.png"
   ["$DT/actions/go-first-symbolic.svg"]="$S_ICOS:marker_first.png $S_ICOS:measure_first.png"
   ["$DT/actions/go-previous-symbolic.svg"]="$S_ICOS:marker_previous.png $S_ICOS:measure_previous.png $S_ICOS:browser_back.png $S_ICOS:arrow_left.png"
   ["$DT/actions/go-next-symbolic.svg"]="$S_ICOS:marker_next.png $S_ICOS:measure_next.png $S_ICOS:arrow_right.png"
   ["$DT/actions/go-last-symbolic.svg"]="$S_ICOS:marker_last.png $S_ICOS:measure_last.png"
+  ["$TG/measure_status_check.svg"]="$S_ICOS:measure_status_check.png"
+  ["$DT/actions/object-select-symbolic.svg"]="$S_ICOS:measure_status_ok.png"
+  ["$DT/actions/process-stop-symbolic.svg"]="$S_ICOS:measure_status_error.png"
   ["$DT/categories/preferences-other-symbolic.svg"]="$S_INFO:option_view.png $S_ICOS:tools_settings.png"
   ["$DT/mimetypes/application-x-addon-symbolic.svg"]="$S_ICOS:tools_plugins.png"
   ["$DT/legacy/preferences-desktop-keyboard-shortcuts-symbolic.svg"]="$S_ICOS:tools_shortcuts.png"
@@ -173,7 +186,7 @@ declare -A ICONS=(
   ["$DT/legacy/preferences-desktop-locale-symbolic.svg"]="$S_INFO:option_language.png"
   ["$DT/legacy/preferences-desktop-appearance-symbolic.svg"]="$S_INFO:option_skin.png"
   ["$DT/devices/audio-speakers-symbolic.svg"]="$S_INFO:option_sound.png"
-  ["$DT/apps/help-contents-symbolic.svg"]="$S_ICOS:help_doc.png"
+  ["$DT/categories/system-help-symbolic.svg"]="$S_ICOS:help_doc.png"
   ["$DT/actions/help-about-symbolic.svg"]="$S_INFO:about_description.png $S_ICOS:help_about.png"
   ["$DT/legacy/system-users-symbolic.svg"]="$S_INFO:about_authors.png"
   ["$DT/legacy/accessories-dictionary-symbolic.svg"]="$S_INFO:about_license.png"
@@ -192,13 +205,15 @@ declare -A ICONS=(
   ["$DT/status/dialog-warning-symbolic.svg"]="$S_INFO:status_warning.png"
   ["$TG/transport_metronome.svg"]="$S_ICOS:transport_metronome.png"
   ["$TG/transport_count_in.svg"]="$S_ICOS:transport_count_in.png"
-  ["$TG/logo.png"]="$S_LOGO:icon.png"
+  ["$TG/transport_time_counter.svg"]="$S_ICOB:transport_time_counter.png"
+  ["$TG/icon.png"]="$SKIN_DIR/icon.png $DARK_DIR/icon.png"
   ["$TG/splash.png"]="$SKIN_DIR/splash.png $DARK_DIR/splash.png"
   ["$TG/skin-preview.png"]="$SKIN_DIR/skin-preview.png"
   ["$TG/skin-preview-dark.png"]="$DARK_DIR/skin-preview.png"
   ["$TG/skin.info"]="$SKIN_DIR/skin.info"
   ["$TG/skin-dark.info"]="$DARK_DIR/skin.info"
-  ["$TG/skin.prop"]="$SKIN_DIR/skin.prop $DARK_DIR/skin.prop"
+  ["$TG/skin.prop"]="$SKIN_DIR/skin.prop"
+  ["$TG/skin-dark.prop"]="$DARK_DIR/skin.prop"
 
 )
 
@@ -206,7 +221,7 @@ function usage {
   echo
   echo "Usage: $COMMAND [OPTIONS]"
   echo
-  echo "Generate the skins $SKIN and $DARK from the SVG/PNG images in the directory"
+  echo "Generate the skins $SKIN and $DARK from the SVG images in the directory"
   echo "  $THIS_DIR"
   echo "  The subfolder \"$DT\" contains the icons that are taken over from the $DT Desktop without modifications."
   echo "  The subfolder \"$TG\" contains icons and other files that are specific to $TG."
@@ -309,18 +324,10 @@ for icon in "${!ICONS[@]}"; do
         OUT_HILI=$C_D_HI
         OUT_FILE=$DARK_DIR/$png_icon
         convert_svg_to_png
-      elif [[ $icon =~ ^.+\.png$ ]]; then
-        echo -n "Converting to $SKIN_DIR/$png_icon ... "
-        if [ $margin ]; then
-          echo -e "\n\nError: Margin $margin given, but margin is not supported for PNGs."
-          echo -e "\nAborting.\n"
-          exit 1
-        fi
-        gm convert -scale $width"x"$height! $THIS_DIR/$icon $SKIN_DIR/$png_icon
-        echo "done."
-        echo -n "Converting to $DARK_DIR/$png_icon ... "
-        cp -p $SKIN_DIR/$png_icon $DARK_DIR
-        echo "done."
+      else
+        echo -e "\nError: Only SVG files can be converted to PNG icons."
+        echo -e "\nAborting.\n"
+        exit 1
       fi
     elif [[ $out_icon =~ .+/.+ ]]; then
       echo -n "Copying to $out_icon ... "
