@@ -25,7 +25,7 @@ DIST_DIR=`pwd`/00-Binary_Packages
 GIT_BRANCH=`git rev-parse --abbrev-ref HEAD`
 
 # Current source version
-TGSRCVER=`grep 'CURRENT = new TGVersion' common/TuxGuitar-lib/src/org/herac/tuxguitar/util/TGVersion.java | awk -F '[(,)]' '{ print $2"."$3"."$4 }'`
+TGSRCVER=`grep 'CURRENT = new TGVersion' common/TuxGuitar-lib/src/main/java/app/tuxguitar/util/TGVersion.java | awk -F '[(,)]' '{ print $2"."$3"."$4 }'`
 
 # Default build version
 TGVERSION=`date +%Y`-`date +%m`-`date +%d`"-$GIT_BRANCH"
@@ -52,7 +52,7 @@ function usage {
   echo "# -m      Build for macOS"
   echo "# -b      Build for FreeBSD"
   echo "# -A      Build for all OS"
-  echo "# -g, -G  Upload the builds to Github"
+  echo "# -g, -G  Upload the builds to GitHub"
   echo "# -r <r>  Set the build version to <r>"
   echo "# -h      Show this help"
   echo "#"
@@ -64,12 +64,12 @@ function usage {
   echo "#"
   echo "# -A: Same as -lwamb"
   echo "#"
-  echo "# -g, -G create a new Github release and upload the builds (from Linux only)."
-  echo "#        -g keeps the release in draft status after the upload. The draft won’t be seen by the"
-  echo "#           public unless it is published manually, either in the Github web interface or with"
+  echo "# -g, -G create a new GitHub release and upload the builds (from Linux only)."
+  echo "#        -g keeps the release in draft status after the upload. The draft won't be seen by the"
+  echo "#           public unless it is published manually, either in the GitHub web interface or with"
   echo "#           the command"
   echo "#           $ gh release edit <release> --draft=false"
-  echo "#           Then, also the release tag will be created on Github."
+  echo "#           Then, also the release tag will be created on GitHub."
   echo "#           After that, you also have to sync the website manually."
   echo "#        -G publishes the release immediately and syncs the website folder to the webserver if"
   echo "#           all files were successfully uploaded. If one or more uploads failed, the release"
@@ -150,10 +150,10 @@ function release_checks_before_prepare_source {
     abort_build
   fi
 
-  echo -n "# Checking download and help links on website ... "
-  if [ "$(grep "Latest stable version ${TGVERSION//\./\\\.}.*${TGVERSION//\./\\\.}" website/index.html | wc -l)" -eq 2 ]; then
+  echo -n "# Checking version on website ... "
+  if [ "$(grep "^const tg_stable=\"${TGVERSION//\./\\\.}\";$" website/vars.js | wc -l)" -eq 1 ]; then
     echo -e "found:"
-    grep "Latest stable version ${TGVERSION//\./\\\.}.*${TGVERSION//\./\\\.}" website/index.html
+    grep "^const tg_stable=\"${TGVERSION//\./\\\.}\";$" website/vars.js
     echo -e "# OK.\n"
   else
     echo -e "not found."
@@ -225,7 +225,7 @@ echo -e "\n### Host: "`hostname -s`" ########### Hacks ..."
 echo -e "\n# Change build version from 9.99-SNAPSHOT to $TGVERSION in config files ..."
   find . \( -name "*.xml" -or -name "*.gradle"  -or -name "*.properties" -or -name "*.html" -or -name control -or -name Info.plist -or -name CHANGES \) -and -not -path "./website/*" -and -type f -exec sed -i -e "s/9.99-SNAPSHOT/$TGVERSION/" '{}' \;
   # Also set the version in the "Help - About" dialog
-  sed -i -e "s/static final String RELEASE_NAME =.*/static final String RELEASE_NAME = (TGApplication.NAME + \" $TGVERSION\");/" desktop/TuxGuitar/src/org/herac/tuxguitar/app/view/dialog/about/TGAboutDialog.java
+  sed -i -e "s/static final String RELEASE_NAME =.*/static final String RELEASE_NAME = (TGApplication.NAME + \" $TGVERSION\");/" desktop/TuxGuitar/src/app/tuxguitar/app/view/dialog/about/TGAboutDialog.java
 echo "# OK."
 
 echo $TGVERSION > .build-version
@@ -468,7 +468,7 @@ function start_remote_macos_build {
 
 # 172.16.208.132: macOS 11 x86_64 (Big Sur)
 # 172.16.208.133: macOS 14 x86_64 (Sonoma)
-BUILD_HOST=$USER@172.16.208.132
+BUILD_HOST=$USER@172.16.208.133
 
 echo -e "\n### Host: "`hostname -s`" ########### Preparing the build for macOS APP on $BUILD_HOST ..."
 SRC_PATH=/Users/$USER/tg-1.x-build-macos
@@ -519,14 +519,12 @@ done
 
 function build_tg_for_android {
 
-BUILD_ARCH=`dpkg --print-architecture`
-
 # Install Android Studio from https://developer.android.com/studio/
-# Android Studio    downloaded to $SW_DIR/android-studio/android-studio-2020.3.1.25-linux.tar.gz   & installed in $SW_DIR/android-studio/android-studio-2020.3.1.25-linux
-# Android SDK Tools downloaded to $SW_DIR/android-studio/commandlinetools-linux-7583922_latest.zip & installed in $SW_DIR/android-studio/android-studio-2020.3.1.25-linux/cmdline-tools/latest/
+# Android Studio    downloaded to $SW_DIR/android-studio/android-studio-2024.2.1.12-linux.tar.gz    & unpacked to $SW_DIR/android-studio/android-studio-2024.2.1.12-linux/
+# Android SDK Tools downloaded to $SW_DIR/android-studio/commandlinetools-linux-11076708_latest.zip & unpacked to $SW_DIR/android-studio/android-studio-2024.2.1.12-linux/cmdline-tools/latest/
 # Initial setup:
-#   export ANDROID_HOME=$SW_DIR/android-studio/android-studio-2020.3.1.25-linux
-#   cd $ANDROID_HOME/bin && ./studio.sh
+#   export ANDROID_HOME=$SW_DIR/android-studio/android-studio-2024.2.1.12-linux
+#   cd $ANDROID_HOME/bin && ./studio
 # Agree to all licenses:
 #   yes | $ANDROID_HOME/cmdline-tools/latest/bin/sdkmanager --licenses
 # Create signature key:
@@ -536,7 +534,7 @@ BUILD_ARCH=`dpkg --print-architecture`
 
 echo -e "\n### Host: "`hostname -s`" ########### Building Android APK ...\n"
 cd android/build-scripts/tuxguitar-android
-export ANDROID_HOME=$SW_DIR/android-studio/android-studio-2020.3.1.25-linux
+export ANDROID_HOME=$SW_DIR/android-studio/android-studio-2024.2.1.12-linux
 echo -e "\n# Executing gradlew:"
 ./gradlew                  # Install the required Gradle version and other stuff into the .gradle/ directory
 echo -e "\n# Executing gradlew assembleRelease:"
@@ -553,28 +551,28 @@ echo -e "\n### Host: "`hostname -s`" ########### Building Android APK done.\n"
 
 function copy_to_github {
 
-  # To edit the repository on Github with the gh command, you have to authenticate first. See 'man gh-auth' for details.
+  # To edit the repository on GitHub with the gh command, you have to authenticate first. See 'man gh-auth' for details.
 
-  echo -e "### Host: "`hostname -s`" ########### Creating a new Github pre-release and upload the builds $TGVERSION to Github ...\n"
+  echo -e "### Host: "`hostname -s`" ########### Creating a new GitHub pre-release and upload the builds $TGVERSION to GitHub ...\n"
 
   cd $SRC_DIR
 
   if [ -z "$(gh release list | grep "^$TGVERSION\s")" ]; then
     if [ $TGVERSION == $TGSRCVER ]; then
-      echo "# Creating Github latest release draft $TGVERSION ..."
+      echo "# Creating GitHub latest release draft $TGVERSION ..."
       RELEASE_TYPE=--latest
     else
-      echo "# Creating Github pre-release draft $TGVERSION ..."
-      REL_NOTES=$'**Warning:** This is a development snapshot and may not be stable.\n\n'
+      echo "# Creating GitHub pre-release draft $TGVERSION ..."
+      REL_NOTES=$'**Warning:** This version of TuxGuitar is our development playground and may not be stable!\n\n'
       RELEASE_TYPE=--prerelease
     fi
-    REL_NOTES=$REL_NOTES$'The Windows packages include OpenJDK from portableapps.com.\nThe macOS package includes OpenJDK from brew.sh.'
-    gh release create $RELEASE_TYPE --draft --title $TGVERSION --notes "$REL_NOTES" $TGVERSION
+    REL_NOTES=$REL_NOTES$'**Please note:** TuxGuitar versions 2.0.0 and later use a **new file format** which cannot be read by older versions. You can still export your tablatures in the old format so that you can open them with older versions of TuxGuitar.\n\nThe Windows packages include OpenJDK from portableapps.com.\nThe macOS package includes OpenJDK from brew.sh.'
+    gh release create --target $GIT_BRANCH $RELEASE_TYPE --draft --title $TGVERSION --notes "$REL_NOTES" $TGVERSION
     # It may take a few sec until the release is ready
     sleep 5
     echo "# OK."
   else
-    echo "# Skipping creation of release $TGVERSION on Github, release already exists."
+    echo "# Skipping creation of release $TGVERSION on GitHub, release already exists."
   fi
   echo
 
@@ -623,7 +621,7 @@ function copy_to_github {
     echo "# Keeping the release in draft status."
   fi
 
-  echo -e "\n### Host: "`hostname -s`" ########### New Github pre-release created and uploads to Github done.\n"
+  echo -e "\n### Host: "`hostname -s`" ########### New GitHub pre-release created and uploads to GitHub done.\n"
 
 }
 
@@ -631,10 +629,10 @@ function copy_to_github {
 [ "$#" -lt 1 ] && usage && exit 1
 [ $build_linux ]    && [ `uname` != Linux ]   && echo -e "\nError: Linux version can only be built on Linux."            && abort_build
 [ $build_windows ]  && [ `uname` != Linux ]   && echo -e "\nError: Windows version can only be built on Linux."          && abort_build
-[ $build_macos ]    && [ `uname` == FreeBSD ] && echo -e "\nError: macOS version cannnot be built on/from FreeBSD."      && abort_build
-[ $build_bsd ]      && [ `uname` == Darwin ]  && echo -e "\nError: FreeBSD version cannnot be built on/from macOS."      && abort_build
+[ $build_macos ]    && [ `uname` == FreeBSD ] && echo -e "\nError: macOS version cannot be built on/from FreeBSD."      && abort_build
+[ $build_bsd ]      && [ `uname` == Darwin ]  && echo -e "\nError: FreeBSD version cannot be built on/from macOS."      && abort_build
 [ $build_android ]  && [ `uname` != Linux ]   && echo -e "\nError: Android version can only be built on Linux."          && abort_build
-[ $copy_to_github ] && [ `uname` != Linux ]   && echo -e "\nError: A new Github release can only be created from Linux." && abort_build
+[ $copy_to_github ] && [ `uname` != Linux ]   && echo -e "\nError: A new GitHub release can only be created from Linux." && abort_build
 
 mkdir -p $SW_DIR
 
@@ -655,7 +653,7 @@ prepare_source
 
 # BSD (on BSD, remote or local)
 if [ $build_bsd ]; then
-  # SWT & JFX versions in FreeBSD 13.2
+  # SWT & JFX versions in FreeBSD 14.2
   SWT_VERSION=4.21
   SWT_PLATFORM=gtk-freebsd
   JFX_VERSION=14.0.2.1
@@ -665,8 +663,8 @@ fi
 
 # macOS (on macOS, remote or local)
 if [ $build_macos ]; then
-  SWT_VERSION=4.14
-  SWT_DATE=201912100610
+  SWT_VERSION=4.36
+  SWT_DATE=202505281830
   SWT_PLATFORM=cocoa-macosx
   [ `uname` == Linux ] && start_remote_macos_build
   [ `uname` == Darwin ] && build_tg_for_macos
@@ -676,26 +674,25 @@ fi
 
 # Linux (local on Linux)
 if [ $build_linux ]; then
-  # SWT version in Debian 12
-  SWT_VERSION=4.26
-  SWT_DATE=202211231800
+  SWT_VERSION=4.36
+  SWT_DATE=202505281830
   SWT_PLATFORM=gtk-linux
   [ `uname` == Linux ] && build_tg_for_linux
 fi
 
 # Windows 64 bit x86_64 build (local on Linux)
 if [ $build_windows ]; then
-  SWT_VERSION=4.26
-  SWT_DATE=202211231800
+  SWT_VERSION=4.36
+  SWT_DATE=202505281830
   SWT_PLATFORM=win32-win32
-  # Get Java for Windows 64 bit from https://portableapps.com/apps/utilities/OpenJDK64
-  PA_JAVA=OpenJDK64_17.0.1-12.paf
-  PA_LINK=https://download3.portableapps.com/portableapps/OpenJDK64/$PA_JAVA.exe
+  # Get Java for Windows 64 bit from https://portableapps.com/apps/utilities/OpenJDKJRE64
+  PA_JAVA=OpenJDKJRE64_21.0.7-6.paf
+  PA_LINK="https://portableapps.com/redir2/?a=OpenJDKJRE64&s=s&d=pa&f=$PA_JAVA.exe"
   [ `uname` == Linux ] && build_tg_for_windows
 fi
 
 # Android build (local on Linux)
 [ `uname` == Linux ] && [ $build_android ] && build_tg_for_android
 
-# Create a new Github release and upload the builds (Linux only)
+# Create a new GitHub release and upload the builds (Linux only)
 [ `uname` == Linux ] && [ $copy_to_github ] && copy_to_github
